/*
 * Copyright (c) 2016, Freescale Semiconductor, Inc.
 * Copyright 2016-2018 NXP
 * All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

#ifndef _BOARD_H_
#define _BOARD_H_

#include "clock_config.h"
#include "fsl_gpio.h"
#include "fsl_port.h"

/*******************************************************************************
 * Definitions
 ******************************************************************************/
/*! @brief The board name */
#define BOARD_NAME "FRDM-K28F"

/*! @brief The UART to use for debug messages. */
#define BOARD_USE_UART
#define BOARD_DEBUG_UART_TYPE kSerialPort_Uart
#define BOARD_DEBUG_UART_BASEADDR (uint32_t) LPUART0
#define BOARD_DEBUG_UART_INSTANCE 0U
#define BOARD_DEBUG_UART_CLKSRC kCLOCK_Osc0ErClk
#define BOARD_DEBUG_UART_CLK_FREQ CLOCK_GetOsc0ErClkFreq()
#define BOARD_UART_IRQ LPUART0_IRQn
#define BOARD_UART_IRQ_HANDLER LPUART0_IRQHandler

#ifndef BOARD_DEBUG_UART_BAUDRATE
#define BOARD_DEBUG_UART_BAUDRATE 115200
#endif /* BOARD_DEBUG_UART_BAUDRATE */

/*! @brief The i2c instance used for i2c connection by default */
#define BOARD_I2C_BASEADDR I2C3

/*! @brief The bubble level demo information */
#define BOARD_FXOS8700_ADDR 0x1C
#define BOARD_ACCEL_ADDR BOARD_FXOS8700_ADDR
#define BOARD_ACCEL_BAUDRATE 100
#define BOARD_ACCEL_I2C_BASEADDR I2C3
#define BOARD_ACCEL_I2C_CLOCK_FREQ CLOCK_GetFreq(I2C3_CLK_SRC)
/*! @brief The TPM instance/channel used for board */
#define BOARD_TPM_BASEADDR TPM2
#define BOARD_TPM_CHANNEL 0U

/*! @brief The FlexBus instance used for board.*/
#define BOARD_FLEXBUS_BASEADDR FB

#define BOARD_TSI_ELECTRODE_CNT 2U

/*! @brief Indexes of the TSI channels for on board electrodes */
#ifndef BOARD_TSI_ELECTRODE_1
#define BOARD_TSI_ELECTRODE_1 11U
#endif
#ifndef BOARD_TSI_ELECTRODE_2
#define BOARD_TSI_ELECTRODE_2 12U
#endif

/*! @brief The SDHC instance/channel used for board */
#define BOARD_SDHC_BASEADDR SDHC

/*! @brief The CMP instance/channel used for board. */
#define BOARD_CMP_BASEADDR CMP1
#define BOARD_CMP_CHANNEL 3U

/*! @brief The i2c instance used for sai demo */
#define BOARD_SAI_DEMO_I2C_BASEADDR I2C0

/*! @brief The rtc instance used for rtc_func */
#define BOARD_RTC_FUNC_BASEADDR RTC

/*! @brief If connected the TWR_MEM, this is spi sd card */
#ifndef BOARD_SDCARD_CARD_DETECTION_GPIO
#define BOARD_SDCARD_CARD_DETECTION_GPIO GPIOD
#endif
#define BOARD_SDCARD_CARD_DETECTION_GPIO_PORT PORTD
#define SDCARD_CARD_DETECTION_GPIO_PIN 15U
#define SDCARD_CARD_WRITE_PROTECTION_GPIO GPIOC
#define SDCARD_CARD_WRITE_PROTECTION_GPIO_PORT PORTC
#define SDCARD_CARD_WRITE_PROTECTION_GPIO_PIN 13U
#define SDCARD_SPI_HW_BASEADDR SPI1
#define SDCARD_CARD_INSERTED 0U

/*! @brief Define the port interrupt number for the board switches */
#ifndef BOARD_SW2_GPIO
#define BOARD_SW2_GPIO GPIOA
#endif
#ifndef BOARD_SW2_PORT
#define BOARD_SW2_PORT PORTA
#endif
#ifndef BOARD_SW2_GPIO_PIN
#define BOARD_SW2_GPIO_PIN 4U
#endif
#define BOARD_SW2_IRQ PORTA_IRQn
#define BOARD_SW2_IRQ_HANDLER PORTA_IRQHandler
#define BOARD_SW2_NAME "SW2"

#ifndef BOARD_SW3_GPIO
#define BOARD_SW3_GPIO GPIOD
#endif
#ifndef BOARD_SW3_PORT
#define BOARD_SW3_PORT PORTD
#endif
#ifndef BOARD_SW3_GPIO_PIN
#define BOARD_SW3_GPIO_PIN 0U
#endif
#define BOARD_SW3_IRQ PORTD_IRQn
#define BOARD_SW3_IRQ_HANDLER PORTD_IRQHandler
#define BOARD_SW3_NAME "SW3"

#define LLWU_SW_GPIO BOARD_SW3_GPIO
#define LLWU_SW_PORT BOARD_SW3_PORT
#define LLWU_SW_GPIO_PIN BOARD_SW3_GPIO_PIN
#define LLWU_SW_IRQ BOARD_SW3_IRQ
#define LLWU_SW_IRQ_HANDLER BOARD_SW3_IRQ_HANDLER
#define LLWU_SW_NAME BOARD_SW3_NAME
/* Board led color mapping */
#define LOGIC_LED_ON 1U
#define LOGIC_LED_OFF 0U
#ifndef BOARD_LED_RED_GPIO
#define BOARD_LED_RED_GPIO GPIOE
#endif
#define BOARD_LED_RED_GPIO_PORT PORTE
#ifndef BOARD_LED_RED_GPIO_PIN
#define BOARD_LED_RED_GPIO_PIN 6U
#endif
#ifndef BOARD_LED_GREEN_GPIO
#define BOARD_LED_GREEN_GPIO GPIOE
#endif
#define BOARD_LED_GREEN_GPIO_PORT PORTE
#ifndef BOARD_LED_GREEN_GPIO_PIN
#define BOARD_LED_GREEN_GPIO_PIN 7U
#endif
#ifndef BOARD_LED_BLUE_GPIO
#define BOARD_LED_BLUE_GPIO GPIOE
#endif
#define BOARD_LED_BLUE_GPIO_PORT PORTE
#ifndef BOARD_LED_BLUE_GPIO_PIN
#define BOARD_LED_BLUE_GPIO_PIN 8U
#endif

#define LED_RED_INIT(output)                                           \
    GPIO_PinWrite(BOARD_LED_RED_GPIO, BOARD_LED_RED_GPIO_PIN, output); \
    BOARD_LED_RED_GPIO->PDDR |= (1U << BOARD_LED_RED_GPIO_PIN) /*!< Enable target LED_RED */

#define LED_RED_ON()                                                                                 \
    GPIO_PortSet(BOARD_LED_RED_GPIO, 1U << BOARD_LED_RED_GPIO_PIN) /*!< Turn on target LED_RED \ \ \ \
                                                                    */
#define LED_RED_OFF() GPIO_PortClear(BOARD_LED_RED_GPIO, 1U << BOARD_LED_RED_GPIO_PIN) /*!< Turn off target LED_RED */
#define LED_RED_TOGGLE() \
    GPIO_PortToggle(BOARD_LED_RED_GPIO, 1U << BOARD_LED_RED_GPIO_PIN) /*!< Toggle on target LED_RED */

#define LED_GREEN_INIT(output)                                             \
    GPIO_PinWrite(BOARD_LED_GREEN_GPIO, BOARD_LED_GREEN_GPIO_PIN, output); \
    BOARD_LED_GREEN_GPIO->PDDR |= (1U << BOARD_LED_GREEN_GPIO_PIN) /*!< Enable target LED_GREEN */
#define LED_GREEN_ON() \
    GPIO_PortSet(BOARD_LED_GREEN_GPIO, 1U << BOARD_LED_GREEN_GPIO_PIN) /*!< Turn on target LED_GREEN */
#define LED_GREEN_OFF() \
    GPIO_PortClear(BOARD_LED_GREEN_GPIO, 1U << BOARD_LED_GREEN_GPIO_PIN) /*!< Turn off target LED_GREEN */
#define LED_GREEN_TOGGLE() \
    GPIO_PortToggle(BOARD_LED_GREEN_GPIO, 1U << BOARD_LED_GREEN_GPIO_PIN) /*!< Toggle on target LED_GREEN */

#define LED_BLUE_INIT(output)                                            \
    GPIO_PinWrite(BOARD_LED_BLUE_GPIO, BOARD_LED_BLUE_GPIO_PIN, output); \
    BOARD_LED_BLUE_GPIO->PDDR |= (1U << BOARD_LED_BLUE_GPIO_PIN)                       /*!< Enable target LED_BLUE */
#define LED_BLUE_ON() GPIO_PortSet(BOARD_LED_BLUE_GPIO, 1U << BOARD_LED_BLUE_GPIO_PIN) /*!< Turn on target LED_BLUE */
#define LED_BLUE_OFF() \
    GPIO_PortClear(BOARD_LED_BLUE_GPIO, 1U << BOARD_LED_BLUE_GPIO_PIN) /*!< Turn off target LED_BLUE */
#define LED_BLUE_TOGGLE() \
    GPIO_PortToggle(BOARD_LED_BLUE_GPIO, 1U << BOARD_LED_BLUE_GPIO_PIN) /*!< Toggle on target LED_BLUE */

/* FLEXIO */
#define BOARD_FLEXIO_I2C_INSTANCE (1)
#define BOARD_FLEXIO_I2C_INSTANCE_BASE (I2C1)
#define BOARD_FLEXIO_INSTANCE (0)
#define BOARD_FLEXIO_INSTANCE_BASE (FLEXIO0)
#define BOARD_FLEXIO_DATA_PINS (8)
#define BOARD_FLEXIO_DATA_PIN_START_INDEX (16)
#define BOARD_FLEXIO_DATA_PIN_END_INDEX (23)
#define BOARD_FLEXIO_PCLK_PIN_INDEX (6)
#define BOARD_FLEXIO_HREF_PIN_INDEX (7)
#define BOARD_FLEXIO_VSYNC_PORT_INDEX (0)
#define BOARD_FLEXIO_VSYNC_PIN_INDEX (20)
#define BOARD_FLEXIO_CLCK_OUT_PORT_INDEX (0)
#define BOARD_FLEXIO_CLCK_OUT_PIN_INDEX (6)
#define BOARD_FLEXIO_RESET_PORT_INDEX (0)
#define BOARD_FLEXIO_RESET_PIN_INDEX (5)

/* SDHC base address, clock and card detection pin */
#define BOARD_SDHC_BASEADDR SDHC
#define BOARD_SDHC_CLKSRC kCLOCK_CoreSysClk
#define BOARD_SDHC_CLK_FREQ CLOCK_GetFreq(kCLOCK_CoreSysClk)
#define BOARD_SDHC_IRQ SDHC_IRQn
#define BOARD_SDHC_CD_GPIO_BASE GPIOB
#ifndef BOARD_SDHC_CD_GPIO_PIN
#define BOARD_SDHC_CD_GPIO_PIN 5U
#endif
#define BOARD_SDHC_CD_PORT_BASE PORTB
#define BOARD_SDHC_CD_PORT_IRQ PORTB_IRQn
#define BOARD_SDHC_CD_PORT_IRQ_HANDLER PORTB_IRQHandler
#define BOARD_SDHC_CARD_INSERT_CD_LEVEL (1U)

/* ERPC DSPI configuration */
#define ERPC_BOARD_DSPI_BASEADDR SPI0
#define ERPC_BOARD_DSPI_BAUDRATE 500000U
#define ERPC_BOARD_DSPI_CLKSRC DSPI0_CLK_SRC
#define ERPC_BOARD_DSPI_CLK_FREQ CLOCK_GetFreq(DSPI0_CLK_SRC)
#define ERPC_BOARD_DSPI_INT_GPIO GPIOC
#define ERPC_BOARD_DSPI_INT_PORT PORTC
#define ERPC_BOARD_DSPI_INT_PIN 11U
#define ERPC_BOARD_DSPI_INT_PIN_IRQ PORTC_IRQn
#define ERPC_BOARD_DSPI_INT_PIN_IRQ_HANDLER PORTC_IRQHandler

/* DAC base address */
#define BOARD_DAC_BASEADDR DAC0

/* Board accelerometer driver */
#define BOARD_ACCEL_FXOS

/* USB PHY condfiguration */
#define BOARD_USB_PHY_D_CAL (0x0CU)
#define BOARD_USB_PHY_TXCAL45DP (0x06U)
#define BOARD_USB_PHY_TXCAL45DM (0x06U)

#if defined(__cplusplus)
extern "C" {
#endif /* __cplusplus */

/*******************************************************************************
 * API
 ******************************************************************************/

void BOARD_InitDebugConsole(void);
#if defined(SDK_I2C_BASED_COMPONENT_USED) && SDK_I2C_BASED_COMPONENT_USED
void BOARD_I2C_Init(I2C_Type *base, uint32_t clkSrc_Hz);
status_t BOARD_I2C_Send(I2C_Type *base,
                        uint8_t deviceAddress,
                        uint32_t subAddress,
                        uint8_t subaddressSize,
                        uint8_t *txBuff,
                        uint8_t txBuffSize);
status_t BOARD_I2C_Receive(I2C_Type *base,
                           uint8_t deviceAddress,
                           uint32_t subAddress,
                           uint8_t subaddressSize,
                           uint8_t *rxBuff,
                           uint8_t rxBuffSize);
void BOARD_Accel_I2C_Init(void);
status_t BOARD_Accel_I2C_Send(uint8_t deviceAddress, uint32_t subAddress, uint8_t subaddressSize, uint32_t txBuff);
status_t BOARD_Accel_I2C_Receive(
    uint8_t deviceAddress, uint32_t subAddress, uint8_t subaddressSize, uint8_t *rxBuff, uint8_t rxBuffSize);
#endif /* SDK_I2C_BASED_COMPONENT_USED */
#if defined(__cplusplus)
}
#endif /* __cplusplus */

#endif /* _BOARD_H_ */
---
project:
  description: the application simulate battery product , it prints the battery percent
    continually. The demo works as DRP. When connect, the board can be source or sink.
  device: MIMXRT595SFFOC:cm33
  components:
  - component: NXP::Device:SDK Utilities:assert_lite
  - component: NXP::Device:SDK Utilities:debug_console_lite
  - component: NXP::NXP Component:OS Abstraction Layer:osa_bm
  - component: NXP::Device:SDK Utilities:baremetal
  - component: NXP::USB:USB Type-C PD Stack:usb_pd
  - component: NXP::Device:SDK Drivers:flexcomm_i2c_adapter
  - component: NXP::Device:SDK Drivers:lists
  - component: NXP::Device:SDK Drivers:mrt_adapter
  - component: NXP::Device:SDK Drivers:rt_gpio_adapter
  - component: NXP::Device:SDK Drivers:usart
  - component: NXP::Device:SDK Drivers:usart_adapter
  - component: NXP::Device:CMSIS:MIMXRT595S_header
  - component: NXP::Device:Startup:MIMXRT595S_startup
  - component: NXP::Device:SDK Drivers:cache
  - component: NXP::Device:SDK Drivers:clock
  - component: NXP::Device:SDK Drivers:common
  - component: NXP::Device:SDK Drivers:evkmimxrt595_flash_config
  - component: NXP::Device:SDK Drivers:flexcomm
  - component: NXP::Device:SDK Drivers:flexspi
  - component: NXP::Device:SDK Drivers:inputmux
  - component: NXP::Device:SDK Drivers:iopctl
  - component: NXP::Device:SDK Drivers:power
  - component: NXP::Device:SDK Drivers:reset
  - component: NXP::USB:USB PD PHY:ptn5110
  - component: NXP::Device:SDK Utilities:misc_utilities
  - component: NXP::NXP Component:OS Abstraction Layer:osa_interface
  - component: NXP::Device:SDK Drivers:i2c
  - component: NXP::Device:SDK Drivers:mrt
  - component: NXP::Device:SDK Drivers:gpio
  - component: ARM::CMSIS:CORE
  - component: NXP::Device:SDK Drivers:iap
  - component: NXP::Device:SDK Drivers:inputmux_connections
  - component: NXP::NXP Component:OS Abstraction Layer:osa
  - component: NXP::USB:USB Type-C PD Stack:config_header
  - component: NXP::USB:USB PD Common Header:common_header
  groups:
  - group: board
    files:
    - file: pin_mux.c
    - file: pin_mux.h
    - file: board.c
    - file: board.h
    - file: clock_config.c
    - file: clock_config.h
  - group: source
    files:
    - file: pd_board_config.h
    - file: pd_app_demo.c
    - file: pd_app.c
    - file: pd_app.h
    - file: pd_command_app.c
    - file: pd_command_interface.c
    - file: pd_command_interface.h
    - file: pd_power_app.c
    - file: pd_power_interface.c
    - file: pd_power_interface.h
    - file: pd_power_nx20p3483.c
    - file: pd_power_nx20p3483.h
  - group: MIMXRT595S/iar
    files:
    - file: iar/MIMXRT595Sxxxx_cm33_ram.icf
      for-compiler:
      - IAR
      for-context:
      - ".debug"
      - ".release"
    - file: iar/MIMXRT595Sxxxx_cm33_flash.icf
      for-compiler:
      - IAR
      for-context:
      - ".flash_debug"
      - ".flash_release"
  - group: MIMXRT595S/arm
    files:
    - file: mdk/MIMXRT595Sxxxx_cm33_ram.scf
      for-compiler:
      - AC6
      for-context:
      - ".debug"
      - ".release"
    - file: mdk/MIMXRT595Sxxxx_cm33_flash.scf
      for-compiler:
      - AC6
      for-context:
      - ".flash_debug"
      - ".flash_release"
  - group: MIMXRT595S/gcc
    files:
    - file: armgcc/MIMXRT595Sxxxx_cm33_ram.ld
      for-compiler:
      - GCC
      for-context:
      - ".debug"
      - ".release"
    - file: armgcc/MIMXRT595Sxxxx_cm33_flash.ld
      for-compiler:
      - GCC
      for-context:
      - ".flash_debug"
      - ".flash_release"
  setups:
  - setup: GCC
    for-compiler: GCC
    for-context: ".flash_debug"
    misc:
    - C:
      - "-DDEBUG"
      - "-DFSL_SDK_DRIVER_QUICK_ACCESS_ENABLE=1"
      - "-DCPU_MIMXRT595SFFOC_cm33"
      - "-DBOOT_HEADER_ENABLE=1"
      - "-DFSL_OSA_BM_TASK_ENABLE=0"
      - "-DFSL_OSA_BM_TIMER_CONFIG=0"
      - "-DI2C_RETRY_TIMES=40000"
      - "-DSDK_DEBUGCONSOLE=1"
      - "-DMCUXPRESSO_SDK"
      - "-g"
      - "-O0"
      - "-mcpu=cortex-m33"
      - "-Wall"
      - "-mfloat-abi=hard"
      - "-mfpu=fpv5-sp-d16"
      - "-mthumb"
      - "-MMD"
      - "-MP"
      - "-fno-common"
      - "-ffunction-sections"
      - "-fdata-sections"
      - "-ffreestanding"
      - "-fno-builtin"
      - "-mapcs"
      - "-std=gnu99"
      ASM:
      - "-DDEBUG"
      - "-D__STARTUP_CLEAR_BSS"
      - "-mcpu=cortex-m33"
      - "-mfloat-abi=hard"
      - "-mfpu=fpv5-sp-d16"
      - "-mthumb"
      CPP:
      - "-DDEBUG"
      - "-DMCUXPRESSO_SDK"
      - "-g"
      - "-O0"
      - "-mcpu=cortex-m33"
      - "-Wall"
      - "-mfloat-abi=hard"
      - "-mfpu=fpv5-sp-d16"
      - "-mthumb"
      - "-MMD"
      - "-MP"
      - "-fno-common"
      - "-ffunction-sections"
      - "-fdata-sections"
      - "-ffreestanding"
      - "-fno-builtin"
      - "-mapcs"
      - "-fno-rtti"
      - "-fno-exceptions"
      Link:
      - "-g"
      - "-mcpu=cortex-m33"
      - "-Wall"
      - "-mfloat-abi=hard"
      - "-mfpu=fpv5-sp-d16"
      - "--specs=nano.specs"
      - "--specs=nosys.specs"
      - "-fno-common"
      - "-ffunction-sections"
      - "-fdata-sections"
      - "-ffreestanding"
      - "-fno-builtin"
      - "-mthumb"
      - "-mapcs"
      - "-Wl,--gc-sections"
      - "-Wl,-static"
      - "-Wl,-z"
      - "-Wl,muldefs"
      - "-Wl,-Map=output.map"
      - "-Wl,--print-memory-usage"
      - "-Wl,--defsym=__stack_size__=0x2000"
      - "-Wl,--defsym=__heap_size__=0x1000"
      Library:
      - "-lm"
      - "-lc"
      - "-lgcc"
      - "-lnosys"
  - setup: GCC
    for-compiler: GCC
    for-context: ".flash_release"
    misc:
    - C:
      - "-DNDEBUG"
      - "-DFSL_SDK_DRIVER_QUICK_ACCESS_ENABLE=1"
      - "-DCPU_MIMXRT595SFFOC_cm33"
      - "-DBOOT_HEADER_ENABLE=1"
      - "-DFSL_OSA_BM_TASK_ENABLE=0"
      - "-DFSL_OSA_BM_TIMER_CONFIG=0"
      - "-DI2C_RETRY_TIMES=40000"
      - "-DSDK_DEBUGCONSOLE=1"
      - "-DMCUXPRESSO_SDK"
      - "-Os"
      - "-mcpu=cortex-m33"
      - "-Wall"
      - "-mfloat-abi=hard"
      - "-mfpu=fpv5-sp-d16"
      - "-mthumb"
      - "-MMD"
      - "-MP"
      - "-fno-common"
      - "-ffunction-sections"
      - "-fdata-sections"
      - "-ffreestanding"
      - "-fno-builtin"
      - "-mapcs"
      - "-std=gnu99"
      ASM:
      - "-DNDEBUG"
      - "-D__STARTUP_CLEAR_BSS"
      - "-mcpu=cortex-m33"
      - "-mfloat-abi=hard"
      - "-mfpu=fpv5-sp-d16"
      - "-mthumb"
      CPP:
      - "-DNDEBUG"
      - "-DMCUXPRESSO_SDK"
      - "-Os"
      - "-mcpu=cortex-m33"
      - "-Wall"
      - "-mfloat-abi=hard"
      - "-mfpu=fpv5-sp-d16"
      - "-mthumb"
      - "-MMD"
      - "-MP"
      - "-fno-common"
      - "-ffunction-sections"
      - "-fdata-sections"
      - "-ffreestanding"
      - "-fno-builtin"
      - "-mapcs"
      - "-fno-rtti"
      - "-fno-exceptions"
      Link:
      - "-mcpu=cortex-m33"
      - "-Wall"
      - "-mfloat-abi=hard"
      - "-mfpu=fpv5-sp-d16"
      - "--specs=nano.specs"
      - "--specs=nosys.specs"
      - "-fno-common"
      - "-ffunction-sections"
      - "-fdata-sections"
      - "-ffreestanding"
      - "-fno-builtin"
      - "-mthumb"
      - "-mapcs"
      - "-Wl,--gc-sections"
      - "-Wl,-static"
      - "-Wl,-z"
      - "-Wl,muldefs"
      - "-Wl,-Map=output.map"
      - "-Wl,--print-memory-usage"
      - "-Wl,--defsym=__stack_size__=0x2000"
      - "-Wl,--defsym=__heap_size__=0x1000"
      Library:
      - "-lm"
      - "-lc"
      - "-lgcc"
      - "-lnosys"
  - setup: GCC
    for-compiler: GCC
    for-context: ".debug"
    misc:
    - C:
      - "-DDEBUG"
      - "-D_DEBUG=1"
      - "-DCPU_MIMXRT595SFFOC_cm33"
      - "-DBOOT_HEADER_ENABLE=1"
      - "-DFSL_OSA_BM_TASK_ENABLE=0"
      - "-DFSL_OSA_BM_TIMER_CONFIG=0"
      - "-DI2C_RETRY_TIMES=40000"
      - "-DSDK_DEBUGCONSOLE=1"
      - "-DMCUXPRESSO_SDK"
      - "-g"
      - "-O0"
      - "-mcpu=cortex-m33"
      - "-Wall"
      - "-mfloat-abi=hard"
      - "-mfpu=fpv5-sp-d16"
      - "-mthumb"
      - "-MMD"
      - "-MP"
      - "-fno-common"
      - "-ffunction-sections"
      - "-fdata-sections"
      - "-ffreestanding"
      - "-fno-builtin"
      - "-mapcs"
      - "-std=gnu99"
      ASM:
      - "-DDEBUG"
      - "-D__STARTUP_CLEAR_BSS"
      - "-mcpu=cortex-m33"
      - "-mfloat-abi=hard"
      - "-mfpu=fpv5-sp-d16"
      - "-mthumb"
      CPP:
      - "-DDEBUG"
      - "-DMCUXPRESSO_SDK"
      - "-g"
      - "-O0"
      - "-mcpu=cortex-m33"
      - "-Wall"
      - "-mfloat-abi=hard"
      - "-mfpu=fpv5-sp-d16"
      - "-mthumb"
      - "-MMD"
      - "-MP"
      - "-fno-common"
      - "-ffunction-sections"
      - "-fdata-sections"
      - "-ffreestanding"
      - "-fno-builtin"
      - "-mapcs"
      - "-fno-rtti"
      - "-fno-exceptions"
      Link:
      - "-g"
      - "-mcpu=cortex-m33"
      - "-Wall"
      - "-mfloat-abi=hard"
      - "-mfpu=fpv5-sp-d16"
      - "--specs=nano.specs"
      - "--specs=nosys.specs"
      - "-fno-common"
      - "-ffunction-sections"
      - "-fdata-sections"
      - "-ffreestanding"
      - "-fno-builtin"
      - "-mthumb"
      - "-mapcs"
      - "-Wl,--gc-sections"
      - "-Wl,-static"
      - "-Wl,-z"
      - "-Wl,muldefs"
      - "-Wl,-Map=output.map"
      - "-Wl,--print-memory-usage"
      - "-Wl,--defsym=__stack_size__=0x2000"
      - "-Wl,--defsym=__heap_size__=0x1000"
      Library:
      - "-lm"
      - "-lc"
      - "-lgcc"
      - "-lnosys"
  - setup: GCC
    for-compiler: GCC
    for-context: ".release"
    misc:
    - C:
      - "-DNDEBUG"
      - "-D_DEBUG=0"
      - "-DCPU_MIMXRT595SFFOC_cm33"
      - "-DBOOT_HEADER_ENABLE=1"
      - "-DFSL_OSA_BM_TASK_ENABLE=0"
      - "-DFSL_OSA_BM_TIMER_CONFIG=0"
      - "-DI2C_RETRY_TIMES=40000"
      - "-DSDK_DEBUGCONSOLE=1"
      - "-DMCUXPRESSO_SDK"
      - "-Os"
      - "-mcpu=cortex-m33"
      - "-Wall"
      - "-mfloat-abi=hard"
      - "-mfpu=fpv5-sp-d16"
      - "-mthumb"
      - "-MMD"
      - "-MP"
      - "-fno-common"
      - "-ffunction-sections"
      - "-fdata-sections"
      - "-ffreestanding"
      - "-fno-builtin"
      - "-mapcs"
      - "-std=gnu99"
      ASM:
      - "-DNDEBUG"
      - "-D__STARTUP_CLEAR_BSS"
      - "-mcpu=cortex-m33"
      - "-mfloat-abi=hard"
      - "-mfpu=fpv5-sp-d16"
      - "-mthumb"
      CPP:
      - "-DNDEBUG"
      - "-DMCUXPRESSO_SDK"
      - "-Os"
      - "-mcpu=cortex-m33"
      - "-Wall"
      - "-mfloat-abi=hard"
      - "-mfpu=fpv5-sp-d16"
      - "-mthumb"
      - "-MMD"
      - "-MP"
      - "-fno-common"
      - "-ffunction-sections"
      - "-fdata-sections"
      - "-ffreestanding"
      - "-fno-builtin"
      - "-mapcs"
      - "-fno-rtti"
      - "-fno-exceptions"
      Link:
      - "-mcpu=cortex-m33"
      - "-Wall"
      - "-mfloat-abi=hard"
      - "-mfpu=fpv5-sp-d16"
      - "--specs=nano.specs"
      - "--specs=nosys.specs"
      - "-fno-common"
      - "-ffunction-sections"
      - "-fdata-sections"
      - "-ffreestanding"
      - "-fno-builtin"
      - "-mthumb"
      - "-mapcs"
      - "-Wl,--gc-sections"
      - "-Wl,-static"
      - "-Wl,-z"
      - "-Wl,muldefs"
      - "-Wl,-Map=output.map"
      - "-Wl,--print-memory-usage"
      - "-Wl,--defsym=__stack_size__=0x2000"
      - "-Wl,--defsym=__heap_size__=0x1000"
      Library:
      - "-lm"
      - "-lc"
      - "-lgcc"
      - "-lnosys"
  - setup: IAR
    for-compiler: IAR
    for-context: ".flash_debug"
    misc:
    - C:
      - "-DDEBUG"
      - "-DFSL_SDK_DRIVER_QUICK_ACCESS_ENABLE=1"
      - "-DBOOT_HEADER_ENABLE=1"
      - "-DCPU_MIMXRT595SFFOC_cm33"
      - "-DFSL_OSA_BM_TASK_ENABLE=0"
      - "-DFSL_OSA_BM_TIMER_CONFIG=0"
      - "-DI2C_RETRY_TIMES=40000"
      - "-DSDK_DEBUGCONSOLE=1"
      - "-DMCUXPRESSO_SDK"
      - "-On"
      - "--diag_suppress Pa082,Pa050"
      - "-e"
      - "--use_c++_inline"
      ASM:
      - "-DDEBUG"
      - "-r"
      - "-s"
      - -M"<>"
      - "-w+"
      - "-j"
      CPP:
      - "-DDEBUG"
      - "-DMCUXPRESSO_SDK"
      - "--debug"
      - "--no_cse"
      - "--no_unroll"
      - "--no_code_motion"
      - "--no_tbaa"
      - "--no_clustering"
      - "--no_scheduling"
      - "--diag_suppress Pa082,Pa050"
      - "-e"
      - "--c++"
      Link:
      - "--config_def __stack_size__=0x2000"
      - "--config_def __heap_size__=0x1000"
  - setup: IAR
    for-compiler: IAR
    for-context: ".flash_release"
    misc:
    - C:
      - "-DFSL_SDK_DRIVER_QUICK_ACCESS_ENABLE=1"
      - "-DCPU_MIMXRT595SFFOC_cm33"
      - "-DBOOT_HEADER_ENABLE=1"
      - "-DNDEBUG"
      - "-DFSL_OSA_BM_TASK_ENABLE=0"
      - "-DFSL_OSA_BM_TIMER_CONFIG=0"
      - "-DI2C_RETRY_TIMES=40000"
      - "-DSDK_DEBUGCONSOLE=1"
      - "-DMCUXPRESSO_SDK"
      - "--diag_suppress Pa082,Pa050"
      - "-e"
      - "--use_c++_inline"
      - "-Oh"
      CPP:
      - "-DNDEBUG"
      - "-DMCUXPRESSO_SDK"
      - "--no_cse"
      - "--no_unroll"
      - "--no_code_motion"
      - "--no_tbaa"
      - "--no_clustering"
      - "--no_scheduling"
      - "--diag_suppress Pa082,Pa050"
      - "-e"
      - "--c++"
      ASM:
      - "-r"
      - "-s"
      - -M"<>"
      - "-w+"
      - "-j"
      Link:
      - "--config_def __stack_size__=0x2000"
      - "--config_def __heap_size__=0x1000"
  - setup: IAR
    for-compiler: IAR
    for-context: ".debug"
    misc:
    - C:
      - "-DDEBUG"
      - "-D_DEBUG=1"
      - "-DCPU_MIMXRT595SFFOC_cm33"
      - "-DBOOT_HEADER_ENABLE=1"
      - "-DFSL_OSA_BM_TASK_ENABLE=0"
      - "-DFSL_OSA_BM_TIMER_CONFIG=0"
      - "-DI2C_RETRY_TIMES=40000"
      - "-DSDK_DEBUGCONSOLE=1"
      - "-DMCUXPRESSO_SDK"
      - "-On"
      - "--debug"
      - "--no_cse"
      - "--no_unroll"
      - "--no_inline"
      - "--no_code_motion"
      - "--no_tbaa"
      - "--no_clustering"
      - "--no_scheduling"
      - "--diag_suppress Pa082,Pa050"
      - "-e"
      - "--use_c++_inline"
      ASM:
      - "-DDEBUG"
      - "-r"
      - "-s"
      - -M"<>"
      - "-w+"
      - "-j"
      CPP:
      - "-DDEBUG"
      - "-DMCUXPRESSO_SDK"
      - "--debug"
      - "--no_cse"
      - "--no_unroll"
      - "--no_code_motion"
      - "--no_tbaa"
      - "--no_clustering"
      - "--no_scheduling"
      - "--diag_suppress Pa082,Pa050"
      - "-e"
      - "--c++"
      Link:
      - "--config_def __stack_size__=0x2000"
      - "--config_def __heap_size__=0x1000"
  - setup: IAR
    for-compiler: IAR
    for-context: ".release"
    misc:
    - C:
      - "-DNDEBUG"
      - "-D_DEBUG=0"
      - "-DCPU_MIMXRT595SFFOC_cm33"
      - "-DBOOT_HEADER_ENABLE=1"
      - "-DFSL_OSA_BM_TASK_ENABLE=0"
      - "-DFSL_OSA_BM_TIMER_CONFIG=0"
      - "-DI2C_RETRY_TIMES=40000"
      - "-DSDK_DEBUGCONSOLE=1"
      - "-DMCUXPRESSO_SDK"
      - "--diag_suppress Pa082,Pa050"
      - "-e"
      - "--use_c++_inline"
      - "-Oh"
      ASM:
      - "-DNDEBUG"
      - "-s"
      - -M"<>"
      - "-w+"
      - "-j"
      CPP:
      - "-DNDEBUG"
      - "-DMCUXPRESSO_SDK"
      - "--diag_suppress Pa082,Pa050"
      - "-e"
      - "--c++"
      Link:
      - "--config_def __stack_size__=0x2000"
      - "--config_def __heap_size__=0x1000"
  - setup: AC6
    for-compiler: AC6
    for-context: ".flash_debug"
    misc:
    - C:
      - "-DDEBUG"
      - "-DFSL_SDK_DRIVER_QUICK_ACCESS_ENABLE=1"
      - "-DCPU_MIMXRT595SFFOC_cm33"
      - "-DBOOT_HEADER_ENABLE=1"
      - "-DFSL_OSA_BM_TASK_ENABLE=0"
      - "-DFSL_OSA_BM_TIMER_CONFIG=0"
      - "-DI2C_RETRY_TIMES=40000"
      - "-DSDK_DEBUGCONSOLE=1"
      - "-DMCUXPRESSO_SDK"
      - "-g"
      - "-O1"
      - "-mcpu=cortex-m33"
      - "-mfpu=fpv5-sp-d16"
      - "-std=c99"
      - "-fshort-enums"
      - "-fshort-wchar"
      - "-ffunction-sections"
      - "-fno-common"
      - "-fdata-sections"
      - "-ffreestanding"
      - "-fno-builtin"
      - "-mthumb"
      - "-fno-rtti"
      ASM:
      - "-DDEBUG"
      CPP:
      - "-DDEBUG"
      - "-DMCUXPRESSO_SDK"
      - "-g"
      - "-O1"
      - "-mcpu=cortex-m33"
      - "-mfpu=fpv5-sp-d16"
      - "-fshort-enums"
      - "-fshort-wchar"
      - "-fno-common"
      - "-ffunction-sections"
      - "-fdata-sections"
      - "-ffreestanding"
      - "-fno-builtin"
      - "-mthumb"
      - "-fno-rtti"
      - "-fno-exceptions"
      Link:
      - "--diag_suppress=6314,6329"
      - "--remove"
      - "--entry=Reset_Handler"
      - "--map"
      - "--xref"
      - "--callgraph"
      - "--symbols"
      - "--info sizes"
      - "--info totals"
      - "--info unused"
      - "--info veneers"
      - "--strict"
      - "--diag_suppress 6314"
      - "--library_type=microlib"
      - --predefine="-D__stack_size__=0x2000"
      - --predefine="-D__heap_size__=0x1000"
  - setup: AC6
    for-compiler: AC6
    for-context: ".flash_release"
    misc:
    - C:
      - "-DNDEBUG"
      - "-DFSL_SDK_DRIVER_QUICK_ACCESS_ENABLE=1"
      - "-DCPU_MIMXRT595SFFOC_cm33"
      - "-DBOOT_HEADER_ENABLE=1"
      - "-DFSL_OSA_BM_TASK_ENABLE=0"
      - "-DFSL_OSA_BM_TIMER_CONFIG=0"
      - "-DI2C_RETRY_TIMES=40000"
      - "-DSDK_DEBUGCONSOLE=1"
      - "-DMCUXPRESSO_SDK"
      - "-Oz"
      - "-mcpu=cortex-m33"
      - "-mfpu=fpv5-sp-d16"
      - "-std=c99"
      - "-fshort-enums"
      - "-fshort-wchar"
      - "-ffunction-sections"
      - "-fno-common"
      - "-fdata-sections"
      - "-ffreestanding"
      - "-fno-builtin"
      - "-mthumb"
      - "-fno-rtti"
      ASM:
      - "-DNDEBUG"
      CPP:
      - "-DNDEBUG"
      - "-DMCUXPRESSO_SDK"
      - "-Oz"
      - "-mcpu=cortex-m33"
      - "-mfpu=fpv5-sp-d16"
      - "-fshort-enums"
      - "-fshort-wchar"
      - "-fno-common"
      - "-ffunction-sections"
      - "-fdata-sections"
      - "-ffreestanding"
      - "-fno-builtin"
      - "-mthumb"
      - "-fno-rtti"
      - "-fno-exceptions"
      Link:
      - "--diag_suppress=6314,6329"
      - "--remove"
      - "--entry=Reset_Handler"
      - "--map"
      - "--xref"
      - "--callgraph"
      - "--symbols"
      - "--info sizes"
      - "--info totals"
      - "--info unused"
      - "--info veneers"
      - "--strict"
      - "--diag_suppress 6314"
      - "--library_type=microlib"
      - --predefine="-D__stack_size__=0x2000"
      - --predefine="-D__heap_size__=0x1000"
  - setup: AC6
    for-compiler: AC6
    for-context: ".debug"
    misc:
    - C:
      - "-DDEBUG"
      - "-D_DEBUG=1"
      - "-DCPU_MIMXRT595SFFOC_cm33"
      - "-DBOOT_HEADER_ENABLE=1"
      - "-DFSL_OSA_BM_TASK_ENABLE=0"
      - "-DFSL_OSA_BM_TIMER_CONFIG=0"
      - "-DI2C_RETRY_TIMES=40000"
      - "-DSDK_DEBUGCONSOLE=1"
      - "-DMCUXPRESSO_SDK"
      - "-g"
      - "-O1"
      - "-mcpu=cortex-m33"
      - "-mfpu=fpv5-sp-d16"
      - "-std=c99"
      - "-fshort-enums"
      - "-fshort-wchar"
      - "-ffunction-sections"
      - "-fno-common"
      - "-fdata-sections"
      - "-ffreestanding"
      - "-fno-builtin"
      - "-mthumb"
      - "-fno-rtti"
      ASM:
      - "-DDEBUG"
      CPP:
      - "-DDEBUG"
      - "-DMCUXPRESSO_SDK"
      - "-g"
      - "-O1"
      - "-mcpu=cortex-m33"
      - "-mfpu=fpv5-sp-d16"
      - "-fshort-enums"
      - "-fshort-wchar"
      - "-fno-common"
      - "-ffunction-sections"
      - "-fdata-sections"
      - "-ffreestanding"
      - "-fno-builtin"
      - "-mthumb"
      - "-fno-rtti"
      - "-fno-exceptions"
      Link:
      - "--diag_suppress=6314,6329"
      - "--remove"
      - "--entry=Reset_Handler"
      - "--map"
      - "--xref"
      - "--callgraph"
      - "--symbols"
      - "--info sizes"
      - "--info totals"
      - "--info unused"
      - "--info veneers"
      - "--strict"
      - "--diag_suppress 6314"
      - "--library_type=microlib"
      - --predefine="-D__stack_size__=0x2000"
      - --predefine="-D__heap_size__=0x1000"
  - setup: AC6
    for-compiler: AC6
    for-context: ".release"
    misc:
    - C:
      - "-DNDEBUG"
      - "-D_DEBUG=0"
      - "-DCPU_MIMXRT595SFFOC_cm33"
      - "-DBOOT_HEADER_ENABLE=1"
      - "-DFSL_OSA_BM_TASK_ENABLE=0"
      - "-DFSL_OSA_BM_TIMER_CONFIG=0"
      - "-DI2C_RETRY_TIMES=40000"
      - "-DSDK_DEBUGCONSOLE=1"
      - "-DMCUXPRESSO_SDK"
      - "-Oz"
      - "-mcpu=cortex-m33"
      - "-mfpu=fpv5-sp-d16"
      - "-std=c99"
      - "-fshort-enums"
      - "-fshort-wchar"
      - "-ffunction-sections"
      - "-fno-common"
      - "-fdata-sections"
      - "-ffreestanding"
      - "-fno-builtin"
      - "-mthumb"
      - "-fno-rtti"
      ASM:
      - "-DNDEBUG"
      CPP:
      - "-DNDEBUG"
      - "-DMCUXPRESSO_SDK"
      - "-Oz"
      - "-mcpu=cortex-m33"
      - "-mfpu=fpv5-sp-d16"
      - "-fshort-enums"
      - "-fshort-wchar"
      - "-fno-common"
      - "-ffunction-sections"
      - "-fdata-sections"
      - "-ffreestanding"
      - "-fno-builtin"
      - "-mthumb"
      - "-fno-rtti"
      - "-fno-exceptions"
      Link:
      - "--diag_suppress=6314,6329"
      - "--remove"
      - "--entry=Reset_Handler"
      - "--map"
      - "--xref"
      - "--callgraph"
      - "--symbols"
      - "--info sizes"
      - "--info totals"
      - "--info unused"
      - "--info veneers"
      - "--strict"
      - "--diag_suppress 6314"
      - "--library_type=microlib"
      - --predefine="-D__stack_size__=0x2000"
      - --predefine="-D__heap_size__=0x1000"
  rte:
    base-dir: "./$TargetType$/RTE"
